@@ -1,7 +1,5 @@
 import importlib
-import json
 import sys
-import tarfile
 
 from modelstore.models.common import save_json
 from modelstore.utils.log import logger
@@ -46,6 +44,5 @@ def save_dependencies(tmp_dir: str, deps: list) -> str:
     return save_json(tmp_dir, _PYTHON_INFO_FILE, deps_info)
 
 
-def save_model_info(tmp_dir, model_name: str, model_info: dict) -> str:
-    model_info["name"] = model_name
+def save_model_info(tmp_dir, model_info: dict) -> str:
     return save_json(tmp_dir, _MODEL_TYPE_FILE, model_info)
