@@ -6,7 +6,11 @@ def sort_by_version(meta_data: dict):
         return datetime.strptime(
             meta_data["code"]["created"], "%Y/%m/%d/%H:%M:%S"
         )
-    return datetime.strptime(meta_data["meta"]["created"], "%Y/%m/%d/%H:%M:%S")
+    if "meta" in meta_data:
+        return datetime.strptime(
+            meta_data["meta"]["created"], "%Y/%m/%d/%H:%M:%S"
+        )
+    return 1
 
 
 def sorted_by_created(versions: list):
